@@ -1,5 +1,6 @@
 package Bitcoin::Crypto;
-$Bitcoin::Crypto::VERSION = '2.000';
+$Bitcoin::Crypto::VERSION = '2.000_01'; # TRIAL
+$Bitcoin::Crypto::VERSION = '2.00001';
 use v5.10;
 use strict;
 use warnings;
@@ -158,9 +159,7 @@ L<https://github.com/bitcoin/bips>
 
 =head1 AUTHOR
 
-Bartosz Jarzyna E<lt>bbrtj.pro@gmail.comE<gt>
-
-Consider supporting: L<https://bbrtj.eu/support>
+Bartosz Jarzyna E<lt>bbrtj.pro@gmail.comE<gt> (L<Support me|https://bbrtj.eu/support>)
 
 =head1 COPYRIGHT AND LICENSE
 
