@@ -1,5 +1,6 @@
 package Bitcoin::Crypto::BIP44;
-$Bitcoin::Crypto::BIP44::VERSION = '2.000';
+$Bitcoin::Crypto::BIP44::VERSION = '2.000_01'; # TRIAL
+$Bitcoin::Crypto::BIP44::VERSION = '2.00001';
 use v5.10;
 use strict;
 use warnings;
@@ -110,7 +111,7 @@ sub as_string
 __END__
 =head1 NAME
 
-Bitcoin::Crypto::BIP44 - BIP44 implementation
+Bitcoin::Crypto::BIP44 - BIP44 implementation in Perl
 
 =head1 SYNOPSIS
 
