@@ -1,5 +1,6 @@
 package Bitcoin::Crypto::Base58;
-$Bitcoin::Crypto::Base58::VERSION = '2.000';
+$Bitcoin::Crypto::Base58::VERSION = '2.000_01'; # TRIAL
+$Bitcoin::Crypto::Base58::VERSION = '2.00001';
 use v5.10;
 use strict;
 use warnings;
@@ -91,7 +92,7 @@ __END__
 
 =head1 NAME
 
-Bitcoin::Crypto::Base58 - Base58 helpers
+Bitcoin::Crypto::Base58 - Bitcoin base58 helpers
 
 =head1 SYNOPSIS
 
