@@ -1,5 +1,6 @@
 package Bitcoin::Crypto::Bech32;
-$Bitcoin::Crypto::Bech32::VERSION = '2.000';
+$Bitcoin::Crypto::Bech32::VERSION = '2.000_01'; # TRIAL
+$Bitcoin::Crypto::Bech32::VERSION = '2.00001';
 use v5.10;
 use strict;
 use warnings;
@@ -306,7 +307,7 @@ __END__
 
 =head1 NAME
 
-Bitcoin::Crypto::Bech32 - Bech32 implementation
+Bitcoin::Crypto::Bech32 - Bitcoin Bech32 implementation
 
 =head1 SYNOPSIS
 
@@ -318,7 +319,6 @@ Bitcoin::Crypto::Bech32 - Bech32 implementation
 		decode_bech32
 		encode_segwit
 		decode_segwit
-		get_hrp
 	);
 
 	# witness version - a number from 0 to 16, packed into a byte
@@ -437,12 +437,6 @@ data in bech32 strings, like so:
 	my $data = encode_bech32('hrp', translate_8to5($bytes));
 	my $decoded = translate_5to8(decode_bech32($data));
 
-=head2 get_hrp
-
-	$hrp = get_hrp($address)
-
-Returns the human readable part encoded in the bech32 address.
-
 =head1 EXCEPTIONS
 
 This module throws an instance of L<Bitcoin::Crypto::Exception> if it
