@@ -1,5 +1,6 @@
 package Bitcoin::Crypto::Block;
-$Bitcoin::Crypto::Block::VERSION = '2.000';
+$Bitcoin::Crypto::Block::VERSION = '2.000_01'; # TRIAL
+$Bitcoin::Crypto::Block::VERSION = '2.00001';
 use v5.10;
 use strict;
 use warnings;
@@ -121,7 +122,7 @@ Returns class instance.
 	$mtp = $object->median_time_past()
 
 This method returns the median time past described in BIP113 (median timestamp
-of previous 11 blocks).
+of the past 11 blocks).
 
 Since this block implementation is as basic as it gets, it will happily
 calculate median time past from less than 11 blocks, if there aren't enough
