@@ -1,19 +1,19 @@
 package Bitcoin::Crypto::Role::ExtendedKey;
-$Bitcoin::Crypto::Role::ExtendedKey::VERSION = '2.000';
+$Bitcoin::Crypto::Role::ExtendedKey::VERSION = '2.000_01'; # TRIAL
+$Bitcoin::Crypto::Role::ExtendedKey::VERSION = '2.00001';
 use v5.10;
 use strict;
 use warnings;
 use Scalar::Util qw(blessed);
 use Mooish::AttributeBuilder -standard;
 use Type::Params -sigs;
-use Carp qw(carp);
 
 use Bitcoin::Crypto::Key::Private;
 use Bitcoin::Crypto::Key::Public;
 use Bitcoin::Crypto::Constants;
 use Bitcoin::Crypto::Types qw(IntMaxBits StrLength Str Object Maybe ByteStr PositiveInt InstanceOf);
 use Bitcoin::Crypto::Util qw(get_path_info hash160 to_format);
-use Bitcoin::Crypto::Helpers qw(ensure_length);
+use Bitcoin::Crypto::Helpers qw(ensure_length carp_once);
 use Bitcoin::Crypto::Network;
 use Bitcoin::Crypto::Exception;
 use Moo::Role;
@@ -265,7 +265,7 @@ sub to_serialized_base58
 	my ($self) = @_;
 
 	my $class = ref $self;
-	carp "$class->to_serialized_base58 is now deprecated. Use to_format [base58 => $class->to_serialized] instead";
+	carp_once "$class->to_serialized_base58 is now deprecated. Use to_format [base58 => $class->to_serialized] instead";
 
 	return to_format [base58 => $self->to_serialized];
 }
@@ -274,7 +274,7 @@ sub from_serialized_base58
 {
 	my ($class, $base58, $network) = @_;
 
-	carp
+	carp_once
 		"$class->from_serialized_base58(\$base58) is now deprecated. Use $class->from_serialized([base58 => \$base58]) instead";
 
 	return $class->from_serialized([base58 => $base58], $network);
