@@ -1,5 +1,6 @@
 package Bitcoin::Crypto::Script;
-$Bitcoin::Crypto::Script::VERSION = '2.000';
+$Bitcoin::Crypto::Script::VERSION = '2.000_01'; # TRIAL
+$Bitcoin::Crypto::Script::VERSION = '2.00001';
 use v5.10;
 use strict;
 use warnings;
@@ -9,12 +10,12 @@ use Mooish::AttributeBuilder -standard;
 use Try::Tiny;
 use Scalar::Util qw(blessed);
 use Type::Params -sigs;
-use Carp qw(carp);
 
 use Bitcoin::Crypto::Constants;
 use Bitcoin::Crypto::Base58 qw(encode_base58check decode_base58check);
 use Bitcoin::Crypto::Bech32 qw(encode_segwit decode_segwit get_hrp);
 use Bitcoin::Crypto::Constants;
+use Bitcoin::Crypto::Helpers qw(carp_once);
 use Bitcoin::Crypto::Util qw(hash160 hash256);
 use Bitcoin::Crypto::Exception;
 use Bitcoin::Crypto::Types qw(Maybe ArrayRef HashRef Str Object ByteStr Any ScriptType ScriptDesc);
@@ -467,7 +468,7 @@ sub get_script
 {
 	my ($self) = @_;
 
-	carp "Bitcoin::Crypto::Script->get_script is deprecated. Use Bitcoin::Crypto::Script->to_serialized instead.";
+	carp_once "Bitcoin::Crypto::Script->get_script is deprecated. Use Bitcoin::Crypto::Script->to_serialized instead.";
 	return $self->to_serialized;
 }
 
@@ -484,7 +485,7 @@ sub get_hash
 
 sub get_script_hash
 {
-	carp "Bitcoin::Crypto::Script->get_script_hash is deprecated. Use Bitcoin::Crypto::Script->get_hash instead.";
+	carp_once "Bitcoin::Crypto::Script->get_script_hash is deprecated. Use Bitcoin::Crypto::Script->get_hash instead.";
 	goto \&get_hash;
 }
 
@@ -667,7 +668,7 @@ sub is_empty
 __END__
 =head1 NAME
 
-Bitcoin::Crypto::Script - Bitcoin Script instance
+Bitcoin::Crypto::Script - Bitcoin script instance
 
 =head1 SYNOPSIS
 
