@@ -1,11 +1,12 @@
 package Bitcoin::Crypto::Segwit;
-$Bitcoin::Crypto::Segwit::VERSION = '2.000';
+$Bitcoin::Crypto::Segwit::VERSION = '2.000_01'; # TRIAL
+$Bitcoin::Crypto::Segwit::VERSION = '2.00001';
 use v5.10;
 use strict;
 use warnings;
 use Exporter qw(import);
-use Carp qw(carp);
 
+use Bitcoin::Crypto::Helpers qw(carp_once);
 use Bitcoin::Crypto::Util;
 
 our @EXPORT_OK = qw(
@@ -19,7 +20,7 @@ our %validators = (
 
 sub validate_program
 {
-	carp
+	carp_once
 		"Bitcoin::Crypto::Segwit::validate_program is deprecated. Use Bitcoin::Crypto::Util::validate_segwit instead.";
 	goto \&Bitcoin::Crypto::Util::validate_segwit;
 }
@@ -29,7 +30,7 @@ sub validate_program
 __END__
 =head1 NAME
 
-Bitcoin::Crypto::Segwit - DEPRECATED
+Bitcoin::Crypto::Segwit - Segregated Witness version validators (DEPRECATED)
 
 =head1 SYNOPSIS
 
